Package: faunabr
Title: Explore Catálogo Taxônomico da Fauna do Brasil Database
Version: 1.1.1
Authors@R: 
    person("Weverton", "Trindade", , "wevertonf1993@gmail.com", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0003-2045-4555"))
Description: A collection of functions designed to retrieve, filter and spatialize data from the Catálogo Taxônomico da Fauna do Brasil. For more information about the dataset, please visit <https://fauna.jbrj.gov.br/fauna/listaBrasil/>.
Imports: XML (>= 3.99.0.14), data.table (>= 1.14.8), httr (>= 1.4.6),
        terra (>= 1.7.39), stats (>= 4.2.3), utils(>= 4.2.3),
License: GPL (>= 3)
Encoding: UTF-8
RoxygenNote: 7.3.3
Depends: R (>= 2.10)
LazyData: true
Suggests: knitr, rmarkdown, testthat (>= 3.0.0)
VignetteBuilder: knitr
BugReports: https://github.com/wevertonbio/faunabr/issues
URL: https://wevertonbio.github.io/faunabr/
NeedsCompilation: no
Packaged: 2026-08-21 01:02:19 UTC; wever
Author: Weverton Trindade [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-2045-4555>)
Maintainer: Weverton Trindade <wevertonf1993@gmail.com>
Repository: CRAN
Date/Publication: 2026-08-21 13:30:25 UTC
Built: R 4.6.0; ; 2026-08-21 14:21:19 UTC; unix
