# Generated by roxygen2: do not edit by hand

export(check_fauna_names)
export(extract_binomial)
export(fauna_attributes)
export(fauna_by_vernacular)
export(fauna_discrepancies)
export(fauna_pam)
export(fauna_spat_occ)
export(fauna_synonym)
export(fauna_version)
export(filter_faunabr)
export(get_faunabr)
export(load_faunabr)
export(merge_data)
export(select_fauna)
export(subset_fauna)
export(translate_faunabr)
importFrom(XML,htmlParse)
importFrom(XML,xmlGetAttr)
importFrom(XML,xpathSApply)
importFrom(data.table,":=")
importFrom(data.table,.SD)
importFrom(data.table,fread)
importFrom(data.table,fwrite)
importFrom(data.table,is.data.table)
importFrom(data.table,rbindlist)
importFrom(data.table,setDT)
importFrom(data.table,setkey)
importFrom(data.table,setnames)
importFrom(grDevices,terrain.colors)
importFrom(httr,GET)
importFrom(httr,write_disk)
importFrom(stats,ave)
importFrom(stats,na.omit)
importFrom(stats,quantile)
importFrom(terra,aggregate)
importFrom(terra,as.data.frame)
importFrom(terra,buffer)
importFrom(terra,intersect)
importFrom(terra,mask)
importFrom(terra,merge)
importFrom(terra,plot)
importFrom(terra,subset)
importFrom(terra,unwrap)
importFrom(terra,vect)
importFrom(utils,adist)
importFrom(utils,read.csv)
importFrom(utils,unzip)
